;; org-init.el --- Org mode initialization settings

;; Copyright (C) 2017 Free Software Foundation, Inc.
;;
;; Author: Carlo Tambuatco <carloftambuatco@iMac.local>
;; Maintainer: Carlo Tambuatco <carloftambuatco@iMac.local>
;; Created: 22 Sep 2017
;; Version: 0.01
;; Keywords

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.



;; Initialize Org Mode
(require 'org)
;(require 'org-install) ; Not required with emacs@29
(require 'org-gcal)
(require 'org-autolist)
(require 'pinentry)
(require 'org-analyzer)
(require 'org-alert)
(require 'org-attach-git)

;;; Load Org markdown exporter
(require 'ox-md nil t)

;;;Customize org modules
(setq org-modules '(ol-bbdb
                      ol-gnus
                      org-habit
                      ol-irc
                      org-mouse
                      org-crypt
                      org-protocol
                      ol-w3m
                      ol-bibtex
                      ol-docview
                      ol-info
                      ol-mhe
                      ol-rmail))

(eval-after-load 'org
 '(org-load-modules-maybe t))

;;; Set default alert system
(setq alert-default-style 'notifier)
;;; Set default interval for receiving alerts
;;; Set to 120 minutes
(setq org-alert-interval (* 2 60 60))
;;; Enable Org Alert
(org-alert-enable)

;;; Use org-bullets to make everything nice and awesome
(require 'org-bullets)
(add-hook 'org-mode-hook (lambda () (org-bullets-mode 1)))

;;; Enable autolist mode in all org buffers
(add-hook 'org-mode-hook (lambda () (org-autolist-mode)))

;;;Org directory
(setf org-directory "~/Documents/Org")

;;;Directory for Org-Analyzer
(setf org-analyzer-directory "~/Documents/Org/Programming/")

;;;Org mode keybindings
(global-set-key "\C-cl" 'org-store-link)
(global-set-key "\C-ca" 'org-agenda-list)
(global-set-key "\C-cA" 'org-agenda)
(global-set-key "\C-cc" 'org-capture)
(global-set-key "\C-cb" 'org-iswitchb)
(global-set-key (kbd "<f5>") 'org-revert-all-org-buffers)
;;;(if (display-graphic-p) (global-set-key (kbd "<f5>") 'org-agenda))
;;;Open all directory links in dired
(add-to-list 'org-file-apps '(directory . emacs))

;;;Org Habit Column Graph
(setq org-habit-graph-column 70)
(setq org-habit-show-habits-only-for-today nil)

;;;Org default span for agenda view
(setq org-agenda-span 'day)

;;;Keep log times hidden
(setq org-log-into-drawer "LOGBOOK")
(setq org-clock-into-drawer 1)

;;;Set behavior of scheduled items with deadlines
;; Non-nil means skip scheduling line if same entry shows because of deadline.

;; In the agenda of today, an entry can show up multiple times
;; because it is both scheduled and has a nearby deadline, and maybe
;; a plain time stamp as well.

;; When this variable is nil, the entry will be shown several times.

;; When set to t, then only the deadline is shown and the fact that
;; the entry is scheduled today or was scheduled previously is not
;; shown.

;; When set to the symbol ‘not-today’, skip scheduled previously,
;; but not scheduled today.

;; When set to the symbol ‘repeated-after-deadline’, skip scheduled
;; items if they are repeated beyond the current deadline.
(setq org-agenda-skip-scheduled-if-deadline-is-shown 'repeated-after-deadline)

;;;Enable org property inheritance
(setq org-use-property-inheritance t)

;;Disable auto-saving
(setq auto-save-default nil)


;; Set Org directories [Remember to update with journal books]
(setq org-agenda-files (list "~/Documents/Org"
                             "~/Documents/Org/Personal"
                             "~/Documents/Org Journals/Training"
                             "~/Documents/Org/Programming"
                             "~/Documents/Org/Work"
                             "~/Documents/Org Journals/Programming Journal"))

;;;Set TODO default sequence
(setq org-todo-keywords
      '((sequence "TODO(t)" "IN_PROGRESS(i)" "|" "DONE(d!)" "POSTPONED(p@)" "CANCELLED(c@)")
        (sequence "TEST(e)" "TESTING(s)" "|" "PASS(p!)" "FAIL(f@)")))

;;;Set TODO keyword faces
(setq org-todo-keyword-faces
      '(("TODO" . (:foreground "#FFAAAA"))
        ("TEST" . (:foreground "#FFAAAA"))
        ("PRACTICE" . (:foreground "#FFAAAA"))
        ("STUDY" . (:foreground "#FFAAAA"))
        ("THEORY" . (:foreground "#FFAAAA"))
        ("WORKOUT" . (:foreground "#9EC9EA" :underline t))
        ("RACE" . (:foreground "#FAFA01" :weight bold))
        ("WATCH" . (:foreground "#FD00D6"))
        ("IN_PROGRESS" . (:foreground "#00E0E7"))
        ("TESTING" . (:foreground "#00E0E7"))
        ("POSTPONED" . (:foreground "#FF7700"))
        ("CANCELLED" . (:foreground "#D42800" :weight bold))
        ("MISSED" . (:foreground "#D42800" :weight bold))
	("IGNORED" . (:foreground "#D72800" :weight bold))
        ("FAIL" . (:foreground "#D42800" :weight bold))))

;;;Set lowest priority to G (ascii 71) for seven piority levels
(setq org-lowest-priority 71)

;;;Org mode log TODO timestamp
(setq org-log-done 'time)

;;;(setq org-agenda-log-mode-items '(closed clock))

;;;Org mode use am/pm time grid style
(setq org-agenda-timegrid-use-ampm t)

;;;Archiving Directory for completed tasks
(setq org-archive-location "~/Documents/Org/Completed.org::* From %s")

;;;Org enforce ordered properties, blocking
(setq org-enforce-todo-dependencies t)

;;;Turn on abbrev-mode in org-mode
(add-hook 'org-mode-hook 'abbrev-mode)
(add-hook 'org-mode-hook 'helm-mode)
(add-hook 'org-mode-hook (lambda () (global-auto-complete-mode -1)))

;; Enable symmetric encrpytion support
(require 'org-crypt)
(setq epg-gpg-program "gpg")
(org-crypt-use-before-save-magic)
(setq org-tags-exclude-from-inheritance (quote ("crypt")))
;; GPG key to use for encryption
;; Either the Key ID or set to nil to use symmetric encryption.
(setq org-crypt-key nil)
(setf epa-pinentry-mode 'loopback)
(pinentry-start)
;(fset 'epg-wait-for-status 'ignore) ;; gpg tends to stall on encryption

;; Set the encoding to utf-8
(setq org-export-coding-system 'utf-8)
(prefer-coding-system 'utf-8)
(set-charset-priority 'unicode)
(setq default-process-coding-system '(utf-8-unix . utf-8-unix))

;;iCalendar export file settings
(setq org-icalendar-include-todo t)
(setq org-icalendar-use-deadline '(event-if-todo todo-due))
(setq org-icalendar-use-scheduled '(event-if-todo))

;; Don't allow editing of folded regions
(setq org-catch-invisible-edits 'error)

;; Start the weekly agenda on Monday
(setq org-agenda-start-on-weekday 1)

;; Enable indentation view, does not effect file.
(setq org-startup-indented t)

;; Make attachments be copied / assigned a uuid
;; and placed in a appropiate folder
(setq org-id-method (quote uuidgen))
(setq org-attach-directory "attach/")

(setq org-tag-persistent-alist '(("@coding" . ?x) ("@design" . ?d)
                                 ("@studying" . ?s) ("@errands" . ?e)
                                 ("@purchases" . ?p) ("crypt" . ?c)
                                 ("@important" . ?i) ("@chore" . ?h)
                                 ("@appointment" . ?a) ("@subject" . ?b)
                                 ("@entertainment" . ?m) ("@event" . ?v)
                                 ("@project" . ?j) ("@reminder" . ?r)))

;; Sync Google calendars to your org files
(require 'org-gcal)

;; Org Grep
;; see https://github.com/pinard/org-grep for usage
(autoload 'org-grep "org-grep" nil t)
(define-key org-mode-map "\C-cng" 'org-grep-full)
(define-key org-mode-map "\C-cog" 'org-grep)

;;Convert all lines in a selected region to an unordered list
(defun org-convert-lines-to-checklist (beg end)
  "Convert all plain lines in region to a plain list with
checkboxes."
  (interactive "r")
  (save-excursion
    (goto-char beg)
    (dotimes (_ (- (line-number-at-pos end) (line-number-at-pos beg)))
      (insert "- [ ] ")
      (indent-according-to-mode)
      (forward-line 1))))

(defun org-convert-lines-to-unordered-list (beg end)
  "Convert all plain lines in region to a plain list without
checkboxes."
  (interactive "r")
  (save-excursion
    (goto-char beg)
    (dotimes (_ (- (line-number-at-pos end) (line-number-at-pos beg)))
      (insert "- ")
      (indent-according-to-mode)
      (forward-line 1))))

;; Org capture settings


;; Allow setting of tags withing org capture buffer
(add-hook 'org-capture-mode-hook
          (lambda ()
            (save-restriction
              (widen)
              (setq-local org-tag-alist (org-get-buffer-tags)))))

;; Org capture templates
(setf org-capture-templates '(("N" "New Note")
                              ("Np" "Personal Note" entry (file+headline
                                                          "~/Documents/Org/Personal/Notes.org"
                                                          "Personal Notes")
                               "* %? \nCaptured On: %t \n%i\n" :empty-lines 1)

                              ("Ns" "Study Note" entry (file+headline
                                                       "~/Documents/Org/Programming/Notes.org"
                                                       "Study Notes")
                               "* %? \nCaptured On: %t \n%i\n" :empty-lines 1)

                              ("Nw" "Work Note" entry (file+headline
                                                       "~/Documents/Org/Work/Notes.org"
                                                       "Work Notes")
                               "* %? \nCaptured On: %^t \n%i\n" :empty-lines 1)
			      ("a" "Appointment" entry (file+headline
                                                        "~/Documents/Org/Personal/Personal_Schedule.org"
                                                        "Appointments")
                               "* TODO %? \nSCHEDULED: %^{when}t DEADLINE: %^{when}t\n:PROPERTIES:\n:COOKIE_DATA: %^{COOKIE_DATA|todo recursive|recursive|nil}p\n:ORDERED: %^{ORDERED|t|nil}p\n:END:\n" :empty-lines 1)

                              ("d" "Due Date" entry (file+headline
                                                        "~/Documents/Org/Personal/Personal_Schedule.org"
                                                        "Due Dates")
                               "* TODO %? \nDEADLINE: %^{when}t\n:PROPERTIES:\n:COOKIE_DATA: %^{COOKIE_DATA|todo recursive|recursive|nil}p\n:END:\n" :empty-lines 1)

                              ("e" "Event" entry (file+headline
                                                        "~/Documents/Org/Personal/Personal_Schedule.org"
                                                        "Events")
                               "* TODO %? \nSCHEDULED: %^{when}t\n" :empty-lines 1)
			      ("t" "TV Show" entry (file+headline
                                                        "~/Documents/Org/Personal/TV_Schedule.org"
                                                        "Current TV Shows:")
                               "* WATCH %? [/]\nSCHEDULED: %^{when}t\n:PROPERTIES:\n:COOKIE_DATA: %^{COOKIE_DATA|checkbox recursive|recursive|nil}p\n:Network: %^{Network|Netflix|AZ Prime|HBO|Cinemax|Showtime|CW|AMC|FX|Fox|Facebook|USA|nil}p\n:ORDERED: %^{ORDERED|t|nil}p\n:STYLE: %^{STYLE|habit|nil}p\n:END:\n:LOGBOOK:\n:END:\nEpisodes:\n1. [ ] " :empty-lines 1)

                              ("m" "Movies / TV / Streaming Events" entry (file+headline
                                                        "~/Documents/Org/Personal/TV_Schedule.org"
                                                        "Movies / TV / Streaming Events")
                               "* WATCH %? \nSCHEDULED: %^{when}t\n:PROPERTIES:\n:Network: %^{Network|Netflix|AZ Prime|HBO|Cinemax|Showtime|CW|AMC|FX|Fox|USA|DVD|nil}p\n:END:\n" :empty-lines 1)

			      ("B" "New Book")
			      ("Bn" "Novel" entry (file+headline
						   "~/Documents/Org/Personal/Books_Read.org"
						   "Novels Read")
			       "* TODO %? \n:PROPERTIES:\n:AUTHOR: %^{AUTHOR}p\n:END:\n"
			       :empty-lines 1)

			      ("Bf" "Nonfiction" entry (file+headline
						   "~/Documents/Org/Personal/Books_Read.org"
						   "Nonfiction Read")
			       "* TODO %? \n:PROPERTIES:\n:AUTHOR: %^{AUTHOR}p\n:TOPIC: %^{TOPIC}p\n:END:\n"
			       :empty-lines 1)

                              ("r" "Race" entry (file+headline
                                                 "~/Documents/Org/Personal/Workouts.org"
                                                 "Scheduled Races")
                               "* RACE %? \nSCHEDULED: %^{when}t" :empty-lines 1)

                              ("R" "New Reminder")

                              ("Rr" "Reminder" entry (file+headline
                                                     "~/Documents/Org/Personal/Personal_Schedule.org"
                                                     "Reminders")
                               "* TODO %? \n:PROPERTIES:\n:COOKIE_DATA: %^{COOKIE_DATA|todo recursive|recursive|nil}p\n:ORDERED: %^{ORDERED|t|nil}p\n:STYLE: %^{STYLE|habit|nil}p\n:END:\n" :empty-lines 1)

                              ("Rg" "Game Release Date" entry (file+headline
                                                     "~/Documents/Org/Personal/Personal_Schedule.org"
                                                     "Reminders")
                               "* TODO %? \nSCHEDULED: %^{when}t\n:PROPERTIES:\n:Console: %^{Console|PS5|PC}p\n:END:\n" :empty-lines 1)

			      ("C" "New Chore(s)/Task(s)")

			      ("Ct" "Task" entry (file+headline
						  "~/Documents/Org/Personal/Personal_Schedule.org"
						  "Tasks")
			       "* TODO %? \nSCHEDULED: %^{when}t\n:PROPERTIES:\n:COOKIE_DATA: %^{COOKIE_DATA|todo recursive|checkbox recursive|recursive|nil}p\n:ORDERED: %^{ORDERED|nil|t}p\n:END:\n" :empty-lines 1)
			      ("Ch" "Chores" entry (file+headline
						  "~/Documents/Org/Personal/Personal_Schedule.org"
						  "Chores")
			       "* TODO %? \nSCHEDULED: %^{when}t\n:PROPERTIES:\n:COOKIE_DATA: %^{COOKIE_DATA|todo recursive|checkbox recursive|recursive|nil}p\n:ORDERED: %^{ORDERED|nil|t}p\n:END:\n" :empty-lines 1)
			      ))

;;Hide all scheduled tasks if DONE
(setf org-agenda-skip-scheduled-if-done t)

;;Org Custom Commands

;;Appointments, Reminders and Chores
(add-to-list 'org-agenda-custom-commands
             '("r" . "Reminders, Appointments and Chores"))
(add-to-list 'org-agenda-custom-commands
             '("rr" "Reminders" tags "+@reminder/!TODO"))
(add-to-list 'org-agenda-custom-commands
             '("ra" "Appointments" tags "+@appointment/!TODO"))
(add-to-list 'org-agenda-custom-commands
             '("rh" "Chores (Domestic)" tags "+@chore/!TODO|IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
             '("rd" "Today's Daily Chores" tags "+SCHEDULED<\"<tomorrow>\"+CATEGORY=\"Daily_Chores\""))
(add-to-list 'org-agenda-custom-commands
             '("rt" "Today's Tasks" tags "+SCHEDULED<\"<tomorrow>\"+CATEGORY=\"Task\"/!-DONE-FINISHED-WATCHED"))
(add-to-list 'org-agenda-custom-commands
             '("rA" "Today's Completed Tasks" tags "+TIMESTAMP_IA>=\"<today>\"+TIMESTAMP_IA<\"<tomorrow>\""))
(add-to-list 'org-agenda-custom-commands
               '("rg" "Game Release Dates" tags "+Console=\"PS4\"|Console=\"PS5\"/!TODO"))

;;Workouts
(add-to-list 'org-agenda-custom-commands
             '("W" "Workouts" tags "+@conditioning/!WORKOUT|IN_PROGRESS"))

;;All Tasks in Progress or Postponed
(add-to-list 'org-agenda-custom-commands
             '("P" . "Tasks In Progress/Postponed" ))
(add-to-list 'org-agenda-custom-commands
             '("Pi" "In Progress" tags "/IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
             '("Pp" "Postponed" tags "/POSTPONED"))

;;Testing
(add-to-list 'org-agenda-custom-commands
             '("t" . "Tests"))
(add-to-list 'org-agenda-custom-commands
             '("ti" "Tests in Progress" tags "/TESTING"))
(add-to-list 'org-agenda-custom-commands
             '("tp" "Tests Passed" tags "/PASS"))
(add-to-list 'org-agenda-custom-commands
             '("tf" "Tests Failed" tags "/FAIL"))

;;Deadlines
(add-to-list 'org-agenda-custom-commands
             '("d" . "Deadlines"))
(add-to-list 'org-agenda-custom-commands
             '("da" "All Deadlines" tags "+DEADLINE>=\"<now>\"/!"))
(add-to-list 'org-agenda-custom-commands
             '("di" "Imminent Deadlines" tags "+DEADLINE<=\"<+2w>\"/!"))
(add-to-list 'org-agenda-custom-commands
             '("dI" "Important Deadlines" tags "+{@important}+DEADLINE>=\"<now>\"/!"))

;;Music Practice
(add-to-list 'org-agenda-custom-commands
             '("i" . "Music Instrument Practice"))
(add-to-list 'org-agenda-custom-commands
             '("ig" "Guitar Practice" tags "Guitar"))
(add-to-list 'org-agenda-custom-commands
             '("ip" "Piano Practice" tags "Piano"))

;;Events and Entertainment
(add-to-list 'org-agenda-custom-commands
             '("E" . "Events and Entertainment"))
(add-to-list 'org-agenda-custom-commands
             '("Ea" "All Events" tags "+{@event}/!TODO|WATCH"))
(add-to-list 'org-agenda-custom-commands
             '("Eu" "Upcoming Events (Next 2 weeks)" tags "+SCHEDULED<=\"<+2w>\"+{@event}/!TODO|WATCH"))
(add-to-list 'org-agenda-custom-commands
             '("Et" "Television and Movies" tags "+{@television\|@streaming\|@entertainment}/!WATCH"))

;;Subjects
(add-to-list 'org-agenda-custom-commands
             '("b" . "Study Subjects and Books"))
(add-to-list 'org-agenda-custom-commands
             '("ba" "All Subjects" tags "+@subject-@unimportant/!TODO|IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
             '("bu" "Unimportant Subjects" tags "+@unimportant/!TODO|IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
             '("bc" "Current Subjects" tags "+@subject-@unimportant+TIMESTAMP_IA>=\"<-21d>\"+/!TODO|IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
             '("br" "Recent Subjects" tags "+@subject-@unimportant+TIMESTAMP_IA>=\"<-4d>\"+/!TODO|IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
             '("bl" "Less Recent Subjects"
               tags "+@subject-@unimportant+TIMESTAMP_IA<\"<-4d>\"+TIMESTAMP_IA>=\"<-10d>\"+/!TODO|IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
             '("bi" "Current ignored subjects"
               tags "+@subject-@unimportant+TIMESTAMP_IA>=\"<-21d>\"+TIMESTAMP_IA<\"<-10d>\"+/!TODO|IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
	         '("bb" . "Books"))
(add-to-list 'org-agenda-custom-commands
	         '("bbr" "Recent Books"
               tags "+@books+TIMESTAMP_IA>=\"<2023-01-01>\""))
(add-to-list 'org-agenda-custom-commands
	         '("bbn" "Current novels"
	           tags "+CATEGORY=\"novel\"+/!IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
	         '("bbN" "All novels"
	           tags "+CATEGORY=\"novel\""))
(add-to-list 'org-agenda-custom-commands
	         '("bbb" "Current nonfiction"
	           tags "+CATEGORY=\"nonfiction\"+/!IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
	         '("bbB" "All nonfiction"
	           tags "+CATEGORY=\"nonfiction\""))
(add-to-list 'org-agenda-custom-commands
	         '("bbt" "Current textbooks"
	           tags "+CATEGORY=\"textbook\"+/!IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
	         '("bbT" "All textbooks"
	           tags "+CATEGORY=\"textbook\""))
(add-to-list 'org-agenda-custom-commands
	     '("bbI" "All In Progress"
	       tags "+@books+/!IN_PROGRESS"))
(add-to-list 'org-agenda-custom-commands
	     '("bbU" "All Unread"
	       tags "+@books+/!TODO"))

;;Notes
(add-to-list 'org-agenda-custom-commands
             '("N" . "Notes"))
(add-to-list 'org-agenda-custom-commands
             '("Np" "Personal Notes" tags "Personal_Notes"))
(add-to-list 'org-agenda-custom-commands
             '("Ns" "Study Notes" tags "Study_Notes"))
(add-to-list 'org-agenda-custom-commands
             '("Nw" "Work Notes" tags "Work_Notes"))

;; ----------------
;; Journal SYSTEM !
;; ----------------

;; SETUP A ROBUST / GENERAL JOURNAL SYSTEM
;; I have modified this from:
;; https://aqeelakber.com/2016/12/21/emacs-org-mode-journal-and-log/
;; Optional Journaling system, record

;; Author name to be auto inserted in entries
(setq journal-author "Carlo Tambuatco")

;; This is the base folder where all your "books"
;; will be stored.
(setq journal-base-dir "~/Documents/Org Journals/")

;; Journal Key bindings
(global-set-key (kbd "C-c j") 'journal-today)
(global-set-key (kbd "C-c e") 'browse-journal)


;; These are your "books" (folders), add as many as you like.
;; Note: "sub volumes" are acheivable with sub folders.
(setq journal-books '("Training"
                      "Blender"
                      "Programming Journal"
                      "Personal Journal"
                      "Japanese"
                      "Guitar"
                      "Investing"
                      "Piano"
                      ))


;; Functions for journal
(defun get-journal-file-today (book)
  "Return today's filename for a books journal file."
  (interactive (list (completing-read "Book: " journal-books) ))
  (expand-file-name
   (concat journal-base-dir book "/J"
	   (format-time-string "%Y-%m-%d") ".org" )) )

(defun journal-today ()
  "Load todays journal entry for book"
  (interactive)
  (find-file (call-interactively 'get-journal-file-today)) )

(defun go-to-journal-dir (book)
  "Go to a journal directory based on a given Book"
  (interactive (list (completing-read "Goto Book: " journal-books)))
          (concat journal-base-dir book)
  )

(defun browse-journal ()
  "Browse an existing journal directory"
  (interactive)
  (dired (call-interactively 'go-to-journal-dir)))


(defun journal-entry-date ()
  "Inserts the journal heading based on the file's name."
  (when (string-match
	 "\\(J\\)\\(20[0-9][0-9]\\)\\-\\([0-9][0-9]\\)\\-\\([0-9][0-9]\\)\\(.org\\)"
	 (buffer-name))
    (let ((year  (string-to-number (match-string 2 (buffer-name))))
          (month (string-to-number (match-string 3 (buffer-name))))
          (day   (string-to-number (match-string 4 (buffer-name))))
          (datim nil))
      (setq datim (encode-time 0 0 0 day month year))
      (format-time-string "%Y-%m-%d (%A)" datim))))

;; Auto-insert journal header
(auto-insert-mode)
(eval-after-load 'autoinsert
  '(define-auto-insert
     '("\\(J\\)\\(20[0-9][0-9]\\)\\-\\([0-9][0-9]\\)\\-\\([0-9][0-9]\\)\\(.org\\)" . "Journal Header")
     '("Short description: "
       "#+TITLE: Journal Entry - "
       (car
	(last
	 (split-string
	  (file-name-directory buffer-file-name) "/Org/"))) \n
       (concat "#+AUTHOR: " journal-author) \n
       "#+DATE: " (journal-entry-date) \n
       "#+FILETAGS: :"
       (car (split-string (car
	              (last
	               (split-string
	                (file-name-directory buffer-file-name) "/Org/"))) "/")) ":" \n \n
       > _ \n
       )))



;; Org Babel customization for evaluating languages
(org-babel-do-load-languages
 'org-babel-load-languages
 '((emacs-lisp . t)
   (R . t)
   (calc . t)
   (gnuplot . t)
   (java . t)))

;;Use the following in a source block to allow changing of DONE state
;;buffer local only

;; Set TODO entry to DONE when all children are DONE
;;  (defun org-summary-todo (n-done n-not-done)
;;    "Switch entry to DONE when all subentries are done, to TODO otherwise."
;;    (let (org-log-done org-log-states)   ; turn off logging
;;      (org-todo (if (= n-not-done 0) "DONE" "TODO"))))

;; (add-hook 'org-after-todo-statistics-hook 'org-summary-todo nil t)

;;; org-init.el ends here
